=========================
Cotton2K simulation model
=========================


|travis|_ |codecov|_ |commit| |lines of code| |license|


Cotton2K is a cotton simulation model specially adapted for irrigated cotton production in arid regions. It was originally written by `Prof. Avishalom Marani`_, and rewrite in Python by `Tang Ziya`_.

The model software is distributed under `AGPL 3.0 or later`_. This version has been upgraded to run on Python.


If you have any problem, feel free to open an issue.

.. |travis| image:: https://img.shields.io/travis/tcztzy/cotton2k/master
            :alt: Build Status
.. _travis: https://travis-ci.org/tcztzy/cotton2k
.. |codecov| image:: https://img.shields.io/codecov/c/github/tcztzy/cotton2k
             :alt: Codecov
.. _codecov: https://codecov.io/github/tcztzy/cotton2k?branch=master
.. |license| image:: https://img.shields.io/github/license/tcztzy/cotton2k
             :alt: GitHub
.. |commit| image:: https://img.shields.io/github/commit-activity/m/tcztzy/cotton2k
            :alt: GitHub commit activity
.. |lines of code| image:: https://img.shields.io/tokei/lines/github/tcztzy/cotton2k
                   :alt: Lines of code
.. _`Prof. Avishalom Marani`: https://plantscience.agri.huji.ac.il/avishalom-marani
.. _`Tang Ziya`: https://github.com/tcztzy
.. _`AGPL 3.0 or later`: LICENSE